@@ -1,10 +1,10 @@
-/* $Id: SUPDrvInternal.h 126386 2018-11-06 12:57:54Z bird $ */
+/* $Id: SUPDrvInternal.h 127870 2019-01-01 04:34:11Z bird $ */
 /** @file
  * VirtualBox Support Driver - Internal header.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,8 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___SUPDrvInternal_h
-#define ___SUPDrvInternal_h
+#ifndef VBOX_INCLUDED_SRC_Support_SUPDrvInternal_h
+#define VBOX_INCLUDED_SRC_Support_SUPDrvInternal_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 
 /*******************************************************************************
@@ -1082,5 +1085,5 @@ const SUPDRVTRACERREG * VBOXCALL supdrvDTraceInit(void);
 
 RT_C_DECLS_END
 
-#endif
+#endif /* !VBOX_INCLUDED_SRC_Support_SUPDrvInternal_h */
 
